#! /usr/bin/env python2.5

## begin license ##
#
#    Meresco Components are components to build searchengines, repositories
#    and archives, based on Meresco Core.
#    Copyright (C) 2007-2008 SURF Foundation. http://www.surf.nl
#    Copyright (C) 2007-2009 Stichting Kennisnet Ict op school.
#       http://www.kennisnetictopschool.nl
#    Copyright (C) 2009 Delft University of Technology http://www.tudelft.nl
#    Copyright (C) 2009 Tilburg University http://www.uvt.nl
#    Copyright (C) 2007-2009 Seek You Too (CQ2) http://www.cq2.nl
#
#    This file is part of Meresco Components.
#
#    Meresco Components is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Meresco Components is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Meresco Components; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
## end license ##

# optimize for meresco version 2.22

from sys import argv, path
from glob import glob
from fcntl import flock, LOCK_EX, LOCK_NB
from os import unlink, open, O_RDONLY, O_CREAT
from os.path import join as join_path

from merescocomponents.facetindex.merescolucene import IndexWriter, merescoStandardAnalyzer
from merescocomponents.facetindex.lucene import IncludeStopWordAnalyzer
from merescocomponents.facetindex.tools.lucenetools import unlock

def optimize(databasePath):
    # make sure nobody is accessing this database
    lockFile = join_path(databasePath, 'lock')
    fd = open(lockFile, O_RDONLY|O_CREAT)
    flock(fd, LOCK_EX|LOCK_NB)

    indexPath = join_path(databasePath, 'index')
    rm = [join_path(indexPath, 'write.lock'), join_path(indexPath, 'tracker.segments')]
    rm.extend(glob(join_path(indexPath, '*.docids')))
    rm.extend(glob(join_path(indexPath, '*.deleted')))
    for f in rm:
        unlink(f)

    unlock(indexPath)
    writer = IndexWriter(indexPath, merescoStandardAnalyzer, False)
    writer.optimize()
    writer.close()

if __name__ == '__main__':
    args = argv[1:]
    if not args:
        print "Specify database directory"
    else:
        optimize(args[0])
